@@ -12,18 +12,7 @@ from copy import deepcopy
 from pprint import pprint
 from sys import argv
 
-from utaupy import ust as _ust
-
-
-def main():
-    """
-    直接実行されたときのやつ
-    """
-    print('UTAUプラグイン一時ファイルの読み取りテストをします。')
-    path = input('テキストファイルのパスを入力してください。\n>>> ')
-    plugin = load(path)
-    for note in plugin.values:
-        pprint(note.values, width=200)
+from . import ust as _ust
 
 
 def run(your_function):
@@ -46,16 +35,15 @@ def load(path, mode='r', encoding='shift-jis'):
     USTのやつを一部改変
     """
     ust = _ust.load(path, mode=mode, encoding=encoding)
-    notes = ust.values
     # UtauPluginオブジェクト化
     plugin = UtauPlugin()
-    plugin.version = notes.pop(0)
-    plugin.setting = notes.pop(0)
-    if notes[0].tag == '[#PREV]':
-        plugin.prev = notes.pop(0)
-    if notes[-1].tag == '[#NEXT]':
-        plugin.next = notes.pop(-1)
-    plugin.notes = notes
+    if ust[2].tag == '[#PREV]':
+        plugin.prev = ust.pop(2)
+    if ust[-1].tag == '[#NEXT]':
+        plugin.next = ust.pop(-1)
+    plugin.version = ust.version
+    plugin.setting = ust.setting
+    plugin.notes = ust[2:]
     return plugin
 
 
@@ -66,20 +54,13 @@ class UtauPlugin(_ust.Ust):
     """
 
     def __init__(self):
-        super().__init__()  # self._note = []
+        super().__init__()
         self.version = None  # [#VERSION]
         self.setting = None  # [#SETTING]
         self.prev = None  # [#PREV] のNoteオブジェクト
+        self.__notes = []  # Noteオブジェクトのリスト
         self.next = None  # [#NEXT] のNoteオブジェクト
 
-    @property
-    def notes(self):
-        return self._notes
-
-    @notes.setter
-    def notes(self, l):
-        self._notes = l
-
     def write(self, path, mode='w', encoding='shift-jis'):
         """
         プラグイン用のテキストをファイル出力する。
@@ -87,7 +68,7 @@ class UtauPlugin(_ust.Ust):
         """
         duplicated_self = deepcopy(self)
         lines = []
-        for note in duplicated_self.values:
+        for note in duplicated_self.notes:
             # ノートを解体して行のリストにする
             d = note.values
             lines.append(d.pop('Tag'))
@@ -100,6 +81,20 @@ class UtauPlugin(_ust.Ust):
             f.write(s)
         return s
 
+    @property
+    def notes(self):
+        """
+        ノート部分を返す。Ustのままだと、さらに縮まってしまうため上書き。
+        """
+        return self.__notes
+
+    @notes.setter
+    def notes(self, x):
+        """
+        ノート部分を上書き。
+        """
+        self.__notes = list(x)
+
 
 if __name__ == '__main__':
     main()
